"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JsonTemplateEngine = void 0;
const constants_1 = require("./constants");
const lexer_1 = require("./lexer");
const parser_1 = require("./parser");
const translator_1 = require("./translator");
const utils_1 = require("./utils");
class JsonTemplateEngine {
    constructor(template) {
        this.fn = JsonTemplateEngine.compile(template);
    }
    static compile(template) {
        const lexer = new lexer_1.JsonTemplateLexer(template);
        const parser = new parser_1.JsonTemplateParser(lexer);
        const translator = new translator_1.JsonTemplateTranslator(parser.parse());
        const code = translator.translate();
        return utils_1.CommonUtils.CreateAsyncFunction(constants_1.DATA_PARAM_KEY, constants_1.BINDINGS_PARAM_KEY, code);
    }
    evaluate(data, bindings = {}) {
        return this.fn(data || {}, bindings);
    }
}
exports.JsonTemplateEngine = JsonTemplateEngine;
